==> gnome-software-3.16.1.tar.xz: gnome-software-3.16.1/src/gs-shell-installed.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GS_SHELL_INSTALLED_H
#define __GS_SHELL_INSTALLED_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "gs-page.h"
#include "gs-plugin-loader.h"

G_BEGIN_DECLS

#define GS_TYPE_SHELL_INSTALLED		(gs_shell_installed_get_type ())
#define GS_SHELL_INSTALLED(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GS_TYPE_SHELL_INSTALLED, GsShellInstalled))
#define GS_SHELL_INSTALLED_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GS_TYPE_SHELL_INSTALLED, GsShellInstalledClass))
#define GS_IS_SHELL_INSTALLED(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GS_TYPE_SHELL_INSTALLED))
#define GS_IS_SHELL_INSTALLED_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GS_TYPE_SHELL_INSTALLED))
#define GS_SHELL_INSTALLED_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GS_TYPE_SHELL_INSTALLED, GsShellInstalledClass))

typedef struct GsShellInstalledPrivate GsShellInstalledPrivate;

typedef struct
{
	 GsPage				 parent;
	 GsShellInstalledPrivate	*priv;
} GsShellInstalled;

typedef struct
{
	GsPageClass			 parent_class;
} GsShellInstalledClass;

GType		 gs_shell_installed_get_type	(void);

GsShellInstalled *gs_shell_installed_new	(void);
void		 gs_shell_installed_invalidate	(GsShellInstalled	*shell_installed);
void		 gs_shell_installed_switch_to	(GsShellInstalled	*shell_installed,
						 gboolean		scroll_up);
void		 gs_shell_installed_reload	(GsShellInstalled	*shell_installed);
void		 gs_shell_installed_setup	(GsShellInstalled	*shell_installed,
						 GsShell		*shell,
						 GsPluginLoader		*plugin_loader,
						 GtkBuilder		*builder,
						 GCancellable		*cancellable);

G_END_DECLS

#endif /* __GS_SHELL_INSTALLED_H */

/* vim: set noexpandtab: */

==> gnome-software-3.18.2.tar.xz: gnome-software-3.18.2/src/gs-shell-installed.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GS_SHELL_INSTALLED_H
#define __GS_SHELL_INSTALLED_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "gs-page.h"
#include "gs-plugin-loader.h"

G_BEGIN_DECLS

#define GS_TYPE_SHELL_INSTALLED (gs_shell_installed_get_type ())

G_DECLARE_FINAL_TYPE (GsShellInstalled, gs_shell_installed, GS, SHELL_INSTALLED, GsPage)

GsShellInstalled *gs_shell_installed_new	(void);
void		 gs_shell_installed_invalidate	(GsShellInstalled	*self);
void		 gs_shell_installed_switch_to	(GsShellInstalled	*self,
						 gboolean		scroll_up);
void		 gs_shell_installed_reload	(GsShellInstalled	*self);
void		 gs_shell_installed_setup	(GsShellInstalled	*self,
						 GsShell		*shell,
						 GsPluginLoader		*plugin_loader,
						 GtkBuilder		*builder,
						 GCancellable		*cancellable);

G_END_DECLS

#endif /* __GS_SHELL_INSTALLED_H */

/* vim: set noexpandtab: */
